@@ -9,7 +9,7 @@
 
 imports callbacks into namespace for convenience
 """
-
+import types
 from builtins import str
 import configparser
 import collections
@@ -17,12 +17,18 @@ import traceback
 import functools
 import sys
 
+import sphinx.builders.text
+import sphinx.writers.text
+from docutils.parsers.rst import Parser as RSTParser
+import docutils.utils
+from docutils.frontend import OptionParser
+
 import clasp.click_callbacks
 from clasp.click_callbacks import *
 
-
 callback_help = clasp.click_callbacks.__doc__
 
+
 def add_callback_info(func):
     if func.__doc__ is None:
         func.__doc__ = callback_help
@@ -146,6 +152,34 @@ def click_ext(click):
     """customize click help messages and bash complete"""
     orig_init = click.core.Option.__init__
 
+    parser = RSTParser()
+    cmpt = (RSTParser,)
+    settings = OptionParser(components=cmpt).get_default_values()
+    settings.tab_size = 4
+    document = docutils.utils.new_document('<rst-doc>', settings)
+
+    app = types.SimpleNamespace(
+            srcdir=None,
+            confdir=None,
+            outdir=None,
+            doctreedir="/",
+            events=None,
+            config=types.SimpleNamespace(
+                    text_newlines="native",
+                    text_sectionchars="=",
+                    text_add_secnumbers=False,
+                    text_secnumber_suffix=".",
+                    ),
+            tags=set(),
+            registry=types.SimpleNamespace(
+                    create_translator=lambda s, something,
+                    new_builder: sphinx.writers.text.TextTranslator(
+                            document, new_builder
+                            )
+                    ),
+            )
+    builder = sphinx.builders.text.TextBuilder(app)
+
     def new_init(self, *args, **kwargs):
         orig_init(self, *args, **kwargs)
         if 'show_default' not in kwargs:
@@ -155,12 +189,22 @@ def click_ext(click):
         """modified help text formatter for compatibility with sphinx-click."""
         if self.help:
             formatter.write_paragraph()
-            with formatter.indentation():
-                indent = ' ' * formatter.current_indent
-                formatter.write(indent +
-                                self.help.replace("\n", "\n{}".format(indent)))
+            rst = _process_as_rst(self.help)
+            formatter.indent()
+            for line in rst.splitlines():
+                formatter.write_text(line)
+            formatter.dedent()
             formatter.write_paragraph()
 
+    def _process_as_rst(text):
+        parser.parse(text, document)
+        translator = sphinx.writers.text.TextTranslator(document,
+                                                        builder)
+        document.walkabout(translator)
+        rst = translator.body.replace("\n\n", "\n")
+        document.clear()
+        return rst
+
     def format_options(self, ctx, formatter):
         """Writes all the options into the formatter if they exist."""
         opts = []
@@ -177,11 +221,23 @@ def click_ext(click):
                     rv0[-1] = callback.upper()
                     rv = (''.join(rv0),) + rv[1:]
                 opts.append((a, name, rv))
-        seps = [(i[0], ("\n" + i[1] + "\n", '')) for i in index_seps(opts)]
+        seps = [(i[0], (f"\n{i[1]}" , '')) for i in index_seps(opts)]
         opts = [i[-1] for i in sorted(opts + seps, key=lambda x: (x[0], x[1]))]
         if opts:
             with formatter.section('Options'):
-                formatter.write_dl(opts)
+                maxwidth = sphinx.writers.text.MAXWIDTH
+                indent = ' '*formatter.current_indent
+                for opt in opts:
+                    formatter.write(f"{indent}{opt[0]}\n")
+                    rst = _process_as_rst(opt[1])
+                    formatter.indent()
+                    formatter.indent()
+                    for line in rst.splitlines():
+                        formatter.write_text(line)
+                    formatter.dedent()
+                    formatter.dedent()
+                    formatter.write("\n")
+            sphinx.writers.text.MAXWIDTH = maxwidth
     click.core.Option.__init__ = new_init
     click.core.Command.format_help_text = format_help_text
     click.core.Command.format_options = format_options
@@ -285,7 +341,8 @@ def main_decs(v, writeconfig=True):
         decorator list for main command to manage config file usage
     """
     md = [
-          click.option('--config', '-c', type=click.Path(exists=True)),
+          click.option('--config', '-c', type=click.Path(exists=True),
+                       help="path of config file to load"),
           click.option('--configalias', '-ca',
                        help="store config in alias section. use to store "
                        "multiple settings for same command"),
@@ -296,7 +353,8 @@ def main_decs(v, writeconfig=True):
     ]
     if writeconfig:
         md.append(click.option('--outconfig', '-oc',
-                  type=click.Path(file_okay=True)))
+                  type=click.Path(file_okay=True),
+                  help="path of config file to write/update"))
     return md
 
 
@@ -438,7 +496,9 @@ def setargs(Config, ini, section):
 
 def index_param(ctx, param):
     '''tag param with index to sort by option type for help display'''
-    if param.human_readable_name == 'help':
+    if param.human_readable_name == 'version':
+        a = 11
+    elif param.human_readable_name == 'help':
         a = 10
     elif param.human_readable_name == 'debug':
         a = 9
@@ -472,7 +532,7 @@ def index_seps(params):
         seps.append((3.5, "FLAGS (DEFAULT TRUE):"))
     if 5 in sections:
         seps.append((4.5, "FLAGS (DEFAULT FALSE):"))
-    if [i for i in [8, 9, 10] if i in sections]:
+    if [i for i in [8, 9, 10, 11] if i in sections]:
         seps.append((7.5, 'HELP:'))
     return seps
 
